Eseguire una valutazione dei rischi con OiRA | OiRA

Temi

# Eseguire una valutazione dei rischi con OiRA

## Iniziare una nuova sessione

Per iniziare una nuova valutazione dei rischi, fai clic sul link «Inizia una nuova sessione».

## Aprire una valutazione dei rischi

Dopo aver iniziato una valutazione dei rischi, la potrai recuperare in qualsiasi momento attraverso il pannello di controllo nella sezione «Le mie valutazioni dei rischi». Qui puoi anche iniziare una nuova valutazione dei rischi.

Il pannello di controllo.

## Navigare all’interno di una valutazione dei rischi

Ciascuna valutazione dei rischi ti guida attraverso varie fasi, che sono visibili nel menù principale sul lato sinistro della schermata:

- Preparazione
- Coinvolgimento
- Individuazione + Valutazione
- Piano d’azione
- Relazione
- Stato

La struttura di ciascuno strumento può variare a seconda delle decisioni adottate dai partner OiRA/dagli sviluppatori dello strumento. In alcuni strumenti la fase dell’individuazione e valutazione dei rischi comprende il piano d’azione. In questi casi il menù sulla sinistra è così configurato:

- Preparazione
- Coinvolgimento
- Valutazione
- Relazione
- Stato

## Preparazione

«Preparazione» è la fase in cui avvii ogni sessione/strumento. È qui che assegni alla valutazione dei rischi un nome che successivamente ti permetterà di distinguerla dalle varie altre valutazioni eseguite con lo strumento.

Il collegamento «Per saperne di più su questo strumento…» fornisce ulteriori informazioni sullo strumento selezionato e sulle parti coinvolte nel suo sviluppo.

Dopo aver fatto clic su «Inizia», potrebbe essere necessario rispondere ad alcune domande aggiuntive, a seconda dello strumento utilizzato. Questa schermata preparatoria con le «domande sul profilo» compare soltanto negli strumenti dotati di tale opzione.

Qui puoi:

- selezionare o saltare una o più situazioni, a seconda che esse siano o meno pertinenti per la tua attività imprenditoriale. Scegli «sì» laddove appropriato;
- elencare una pluralità di unità aziendali, succursali, negozi ecc. I relativi rischi saranno ripetuti per ciascuna voce.

La schermata “Profilo” nella fase Preparazione

La fase della preparazione è molto importante perché definisce accuratamente il tipo di impresa e i rischi correlati che la tua azienda deve affrontare. Dopo aver fatto clic su «Salva e continua», si passa alla successiva sezione, «Coinvolgimento».

Nota: molti strumenti non contengono domande sul profilo perché non utilizzano questa funzione per indirizzare lo strumento; in tali strumenti questa schermata viene saltata automaticamente.

## Coinvolgimento

Questa fase serve a ricordare l’importanza del coinvolgimento dei lavoratori e propone vari modi per ottimizzarlo. Qui puoi scaricare o stampare i contenuti della valutazione dei rischi per condividerli con i lavoratori/dipendenti. In tal modo si garantisce che i lavoratori siano in grado di contribuire al compito di valutare la situazione sul loro luogo di lavoro.

## Valutazione

In questa fase individuerai i pericoli e i problemi che sono rilevanti per la tua impresa.

Nota: a seconda del modo in cui lo strumento è stato configurato dal partner OiRA, la fase «Piano d’azione» (cfr. più avanti) può essere integrata in questa schermata. In tal caso, l’intera fase è denominata «Valutazione» e gli elementi descritti nel «Piano d’azione» appariranno nella sezione relativa all’individuazione e valutazione di ciascun rischio.

Individuazione e Valutazione.

Sul lato sinistro dello schermo, nella sezione «Individuazione + Valutazione»/«Valutazione», sono visualizzati tutti gli argomenti/moduli inclusi nello strumento. L’argomento che stai visualizzando è evidenziato.

### Individuazione

Per ciascun rischio devi decidere se l’affermazione che descrive uno stato desiderato sia applicabile alla tua impresa. Puoi rispondere come segue:

- sì: se rispondi all’affermazione con un «sì», non è necessaria alcuna azione ulteriore, perché hai valutato che quel rischio non è presente;
- no: se rispondi all’affermazione con un «no», sono necessarie ulteriori azioni. Ti sarà chiesto di decidere misure specifiche;
- non applicabile: riguardo ad alcune affermazioni sui rischi si può selezionare l’opzione «non applicabile» nel caso in cui il rischio in questione non sia pertinente per la tua impresa/il tuo stabilimento.

Sotto ciascuna affermazione sono abitualmente riportate informazioni supplementari sul rischio specifico:

- informazioni: una breve descrizione, talvolta corredata di immagini accompagnatorie, che fornisce maggiori dettagli sul rischio;
- risorse: informazioni aggiuntive sul rischio, ad esempio riferimenti giuridici e politici. Qualche volta sono allegati anche documenti di approfondimento;
- osservazioni: puoi inserire qui le tue osservazioni, che compariranno nella relazione alla fine della valutazione.

Dopo aver risposto ad un’affermazione su un rischio e proseguendo nel procedimento, il menù sulla sinistra verrà aggiornato con un simbolo colorato che indicherà se hai:

- risposto positivamente (segno di spunta verde);
- risposto negativamente (croce rossa);
- rinviato la risposta (punto di domanda arancione).

Nel caso delle domande prive di risposta rimane il simbolo grigio.

### Valutazione

In questa fase valuti la priorità di un rischio che hai individuato.

Valutare un rischio.

Nota: in alcuni strumenti OiRA la valutazione non è visualizzata. La visualizzazione dipende dal modo in cui il partner/lo sviluppatore dello strumento OiRA nazionale ha impostato quel particolare strumento OiRA.

Se hai indicato che un dato rischio è presente (evidenziato da una freccia rossa), comparirà la sezione per la valutazione. A seconda del metodo di valutazione impostato per ciascun rischio ti verrà chiesto di:

- stimare la priorità: alta, media o bassa

Impostare la priorità di un rischio.

OPPURE

- rispondere ad alcune domande sulla frequenza, la gravità e la probabilità del rischio, per poter determinare la priorità sulla scorta delle tue risposte.

Impostare le variabili di un rischio.

### Rischi prioritari impostati dal settore:

alcuni rischi sono considerati molto importanti dal partner/dallo sviluppatore dello strumento nazionale che ha creato quello specifico strumento OiRA. Non è necessario stimare i «rischi prioritari» perché la loro priorità sarà automaticamente impostata come «alta».

Rischi prioritari.

### Rischi specificamente formulati

Dopo aver finito di rispondere a tutti i punti relativi ai rischi nella sezione «Individuazione + Valutazione»/«Valutazione», giungerai al punto opzionale «Altri rischi». Qui puoi creare le tue voci personalizzate utilizzando il pulsante «Aggiungi un rischio specificamente formulato».

Se lo strumento non contempla rischi che sono presenti sul tuo luogo di lavoro/nella tua impresa, devi aggiungerli qua. Questi rischi possono essere integralmente definiti/formulati da te.

Rischi specificamente formulati.

Un «rischio specificamente formulato» funziona in maniera analoga ai rischi contemplati dallo strumento OiRA, ma ovviamente devi redigere tu il relativo testo, che dovrebbe consistere perlomeno in una breve affermazione che descriva una situazione problematica, con l’opzione di una descrizione più ampia. Puoi anche caricare un’immagine per illustrare una determinata situazione.

Come nel caso dei rischi abituali, devi dichiarare se il rischio è presente oppure no. Questo permetterà di spuntare i rischi specificamente formulati una volta che saranno stati gestiti efficacemente; lascia comunque questi rischi all’interno della valutazione, a fini di documentazione.

Puoi aggiungere tutti i rischi specificamente formulati che consideri pertinenti.

Aggiungere un rischio specificamente formulato.

## Piano d’azione

In questa fase decidi le misure che intendi attuare per eliminare o ridurre i rischi individuati in precedenza.

Nota: come specificato sopra, il piano d’azione è presentato come una fase separata nel menù a sinistra, oppure compare sotto ciascun rischio individuato. In quest’ultimo caso, nel menù la fase è denominata «Valutazione» e comprende sia le affermazioni sui rischi sia opzioni di risposta.

La versione dello strumento utilizzato dipende dalle decisioni adottate dal partner OiRA/dallo sviluppatore dello strumento nazionale.

### Piano d’azione integrato

Piano d’azione integrato.

Se a una domanda rispondi con un «no», sulla pagina si aprirà il modulo del piano d’azione, nella sezione «Misure».

Puoi sia selezionare misure tra quelle proposte nell’elenco del sistema, sia definire le tue misure autonomamente.

### Piano d’azione separato

Se il piano d’azione costituisce una fase separata, sarà accessibile utilizzando le opzioni sul lato sinistro.

Fai clic sul pulsante «Crea un piano d’azione» per iniziare il tuo piano.

Nella fase del piano d’azione, il menù sulla sinistra mostra ora soltanto i rischi che necessitano ulteriori azioni, poiché gli altri rischi sono stati indicati come non presenti.

Per ciascun rischio al quale hai risposto con un «no» durante la fase di valutazione e per i rischi prioritari (indipendentemente dalla risposta, sia stata essa positiva o negativa) ti verrà chiesto di definire misure.

Un rischio nel piano d’azione.

Puoi selezionare misure tra quelle suggerite nell’elenco del sistema oppure definire le tue misure personali.

#### Aggiungi la tua misura

Aggiungere una misura extra.

Usa il pulsante «Aggiungi una misura» per cominciare a definire una misura preventiva. Qui dovresti:

- descrivere l’approccio generale che sarà adottato per eliminare o ridurre il rischio;
- indicare, facoltativamente, il livello di competenze e/o i requisiti necessari (ad esempio, puoi indicare qui se per gestire questo rischio sono richieste una formazione specifica o competenze esterne);
- inserire informazioni sui soggetti responsabili dell’esecuzione;
- stabilire la dotazione finanziaria, se applicabile;
- fissare, facoltativamente, le date previste per l’inizio dell’esecuzione della misura e per il suo completamento.

Puoi aggiungere tutte le misure necessarie.

#### Aggiungi misure standard

A seconda dell’impostazione applicata dal partner OiRA/dallo sviluppatore dello strumento, sono disponibili misure predefinite per i rischi individuali. Puoi scegliere una o più misure predefinite facendo clic sul pulsante «Seleziona misure standard».

Si aprirà un menù pop-up contenente tutte le misure suggerite. Fai clic sul pulsante «Aggiungi» in corrispondenza di quelle che intendi utilizzare.

Le misure predefinite vengono poi elencate nel tuo piano d’azione. La descrizione delle cose da fare è prestabilita, mentre gli altri campi (responsabilità, dotazione finanziaria, date) possono e dovrebbero essere compilati da te.

Aggiungere misure standard.

Sia le misure standard sia quelle definite da te possono essere cancellate in qualsiasi momento.

## Relazione

Dopo aver completato il piano d’azione, puoi produrre una relazione.

Se desideri formulare un’osservazione da includere nella relazione, digita il testo qui e salvalo.

Commenta la relazione.

Vedi qui per ulteriori informazioni sulle diverse relazioni e su come utilizzarle.

## Stato

Il piccolo diagramma circolare nel menù a sinistra mostra lo stato di avanzamento nell’utilizzo dello strumento.

La sezione dello stato offre una panoramica di quanti rischi hai individuato, quanti di essi hai affrontato mediante la definizione di misure e a quanti rischi/affermazioni non hai ancora risposto.

La pagina dello stato.

Quando accedi alla schermata dello stato puoi vedere lo stato di avanzamento in ciascun modulo. In questo modo potrai vedere dove devi ancora valutare i rischi o indicare le misure per affrontare i rischi individuati.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More